@@ -33,4 +33,4 @@ fi
 su -c "mv /tmp/$SRC_PACKAGE $BUILDRPM_DIR/SOURCES; \
 	mv /tmp/$RPM_BASENAME.spec $BUILDRPM_DIR/SPECS; \
 	cd $BUILDRPM_DIR/SPECS; \
-	rpm -ba $RPM_BASENAME.spec"
+	rpm -bs $RPM_BASENAME.spec"
